@@ -1,2 +1,2 @@
-pvalue[0] = 1.0 - pchisq(stat,4.0,1,0); 
+pvalue[0] = 1.0 - pchisq(statistic[0], 4.0, 1, 0); 
 //      if (alter[0] == 0) pvalue[0] = 2 * tmp; else pvalue[0] = tmp; 
